/*******************************************************************************
 * Copyright (C) 2011 Mikołaj Rybiński
 * 
 *     This file is part of Tav4SB.
 * 
 *     Tav4SB is free software: you can redistribute it and/or modify it under the
 *     terms of the GNU Affero General Public License as published by the Free
 *     Software Foundation, either version 3 of the License, or (at your option)
 *     any later version.
 * 
 *     Tav4SB is distributed in the hope that it will be useful, but WITHOUT ANY
 *     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *     FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
 *     more details.
 * 
 *     You should have received a copy of the GNU Affero General Public License
 *     along with Tav4SB. If not, see <http://www.gnu.org/licenses/>.
 * 
 *     Contributors:
 *         Paweł Banasik - initial implementation
 *         Michał Lula - grid implementation
 *         Mikołaj Rybiński - implementation and maintenance
 ******************************************************************************/
package pl.edu.mimuw.bioputer.tav4sb.workflows.bsh;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

import java.io.StringWriter;
import javax.xml.stream.XMLOutputFactory;
import javax.xml.stream.XMLStreamWriter;
import javax.xml.stream.FactoryConfigurationError;
import javax.xml.stream.XMLStreamException;

class ConstObj {
    String name;
    BigDecimal start;
    BigDecimal stop;
    BigDecimal step;
}

public class SetConstantCompactXmlList {

    static ConstObj constant(String conststr) {
        String[] nameAndSss = conststr.split("=");
        if (nameAndSss.length != 2) {
            throw new RuntimeException("Wrong constant declaration format: \""
                    + conststr + "\".");
        }
        String name = nameAndSss[0].trim();

        System.out.println(name);

        String[] sss = nameAndSss[1].split(":");
        if (sss.length < 1 || sss.length > 3) {
            throw new RuntimeException("Wrong constant values format: \""
                    + conststr + "\".");
        }

        BigDecimal start = new BigDecimal(sss[0]);
        BigDecimal step = new BigDecimal("1");
        if (sss.length == 3)
            step = new BigDecimal(sss[1]);
        BigDecimal stop = new BigDecimal(sss[sss.length - 1]);

        ConstObj ret = new ConstObj();
        ret.name = name;
        ret.start = start;
        ret.stop = stop;
        ret.step = step;

        return ret;
    }

    static List<BigDecimal> values(ConstObj constobj) {
        int i = 0;

        BigDecimal start = constobj.start;
        BigDecimal step = constobj.step;
        BigDecimal stop = constobj.stop;

        List<BigDecimal> ret = new LinkedList<BigDecimal>();
//		List<BigDecimal> ret = new ArrayList<BigDecimal>(stop.subtract(start).divide(step).intValue()+1);
        for (BigDecimal ibd = start; ibd.compareTo(stop) <= 0; ibd = ibd
                .add(step)) {
            ret.add(ibd);

            System.out.println(ibd);
            i++;
        }
//		System.out.println((stop.subtract(start).divide(step).intValue() + 1)
//				+ " vs. " + i);
        return ret;
    }

    static String CONSTANT_VALUES_TAGNAME = "constantValues";
    static String NAME_ATTRNAME = "name";
    static String VALUE_TAGNAME = "value";

    static String toTag(ConstObj constobj) throws XMLStreamException, FactoryConfigurationError {
        StringWriter sw = new StringWriter();
        XMLStreamWriter xw = XMLOutputFactory.newInstance().createXMLStreamWriter(sw);

        xw.writeStartDocument();
        xw.writeStartElement(CONSTANT_VALUES_TAGNAME);
        xw.writeAttribute(NAME_ATTRNAME, constobj.name);
        for (BigDecimal value: values(constobj)) {
            xw.writeStartElement(VALUE_TAGNAME);
            xw.writeCharacters(value.toString());
            xw.writeEndElement();
        }
        xw.writeEndElement();
        xw.writeEndDocument();

        String ret = sw.toString();

        System.out.println(ret);
        return ret;
    }

    /**
     * @param args
     * @throws FactoryConfigurationError
     * @throws XMLStreamException
     */
    public static void main(String[] args) throws XMLStreamException, FactoryConfigurationError {
        String input = "t=0:0.11:1.05,u=1:10,w=1";

        List<String> output = new LinkedList<String>();
        if (!input.isEmpty()) {
            for (String conststr: input.split(",")) {
                output.add(toTag(constant(conststr)));
            }
        }
    }

}
