/*******************************************************************************
 * Copyright (C) 2011 Mikołaj Rybiński
 * 
 *     This file is part of Tav4SB.
 * 
 *     Tav4SB is free software: you can redistribute it and/or modify it under the
 *     terms of the GNU Affero General Public License as published by the Free
 *     Software Foundation, either version 3 of the License, or (at your option)
 *     any later version.
 * 
 *     Tav4SB is distributed in the hope that it will be useful, but WITHOUT ANY
 *     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *     FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
 *     more details.
 * 
 *     You should have received a copy of the GNU Affero General Public License
 *     along with Tav4SB. If not, see <http://www.gnu.org/licenses/>.
 * 
 *     Contributors:
 *         Paweł Banasik - initial implementation
 *         Michał Lula - grid implementation
 *         Mikołaj Rybiński - implementation and maintenance
 ******************************************************************************/
package pl.edu.mimuw.bioputer.tav4sb.workflows.bsh;

import java.io.ByteArrayInputStream;
import java.io.IOException;

import javax.xml.parsers.ParserConfigurationException;
import org.w3c.dom.Element;
import org.xml.sax.SAXException;

import java.util.Arrays;

import javax.xml.stream.FactoryConfigurationError;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamWriter;

import java.util.List;
import java.util.ArrayList;
import java.math.BigDecimal;
import java.math.MathContext;
import java.io.StringWriter;
import javax.xml.stream.XMLOutputFactory;
import javax.xml.parsers.DocumentBuilderFactory;

public class SetParamsRange {

    static class OldParamObj {
        String name;
        String reaction;
        BigDecimal value;
        BigDecimal upperBound;
        BigDecimal lowerBound;
    }

    static OldParamObj parameter(String n, String t, BigDecimal v, BigDecimal ub, BigDecimal lb) {
        OldParamObj ret = new OldParamObj();

        String[] nameCtx = n.split("\\.");
        if (nameCtx.length > 2) {
            throw new RuntimeException("Wrong SBML parameter name format: \""
                    + n + "\".");
        } else if (nameCtx.length > 1) {
            ret.name = nameCtx[1];
            ret.reaction = nameCtx[0];
        } else {
            ret.name = nameCtx[0];
            ret.reaction = (t == null ? null: "");
        }
        ret.value = v;
        ret.upperBound = ub;
        ret.lowerBound = lb;

        return ret;
    }

    static String PARAMS_TAGNAME = "paramList";
    static String PARAM_TAGNAME = "param";
    static String NAME_ATTRNAME = "name";
    static String TYPE_ATTRNAME = "type";
    static String REACTION_ATTRNAME = "reaction";
    static String VALUE_ATTRNAME = "value";
    static String UB_ATTRNAME = "upperBound";
    static String LB_ATTRNAME = "lowerBound";

    static String toTag(List<OldParamObj> paramlist) throws XMLStreamException,
            FactoryConfigurationError {
        StringWriter sw = new StringWriter();
        XMLStreamWriter xw = XMLOutputFactory.newInstance()
                .createXMLStreamWriter(sw);

        xw.writeStartDocument();
        xw.writeStartElement(PARAMS_TAGNAME);

        for (OldParamObj paramobj : paramlist) {
            xw.writeStartElement(PARAM_TAGNAME);
            xw.writeAttribute(NAME_ATTRNAME, paramobj.name);
            if (paramobj.reaction != null)
                xw.writeAttribute(REACTION_ATTRNAME, paramobj.reaction);
            xw.writeAttribute(VALUE_ATTRNAME, paramobj.value.toString());
            xw.writeAttribute(UB_ATTRNAME, paramobj.upperBound.toString());
            xw.writeAttribute(LB_ATTRNAME, paramobj.lowerBound.toString());
            xw.writeEndElement();
        }

        xw.writeEndElement();
        xw.writeEndDocument();

        return sw.toString();
    }

    public static void main(String[] args) throws SAXException, IOException,
            ParserConfigurationException, XMLStreamException,
            FactoryConfigurationError {
        List<String> paramXmlList = Arrays.asList(
                "<param name=\"k1.k\" type=\"kinetic\">0.18</param>",
                "<param name=\"k3\" type=\"kinetic\">0.21</param>"
        );
        String multiplier = "10";

        List<OldParamObj> params = new ArrayList<OldParamObj>(paramXmlList.size());
        BigDecimal m = new BigDecimal(multiplier);
        for (String paramXml : paramXmlList) {
            Element paramEl = DocumentBuilderFactory.newInstance().newDocumentBuilder().parse(new ByteArrayInputStream(paramXml.getBytes())).getDocumentElement();
            BigDecimal nv = new BigDecimal(paramEl.getTextContent());
            params.add(parameter(
                paramEl.getAttributes().getNamedItem(NAME_ATTRNAME).getNodeValue(),
                paramEl.getAttributes().getNamedItem(TYPE_ATTRNAME).getNodeValue(),
                nv, nv.multiply(m), nv.divide(m, MathContext.DECIMAL128)
            ));
        }

        String paramListXml = toTag(params);

        System.out.println(paramListXml);
    }

}
