/*******************************************************************************
 * Copyright (C) 2011 Mikołaj Rybiński
 * 
 *     This file is part of Tav4SB.
 * 
 *     Tav4SB is free software: you can redistribute it and/or modify it under the
 *     terms of the GNU Affero General Public License as published by the Free
 *     Software Foundation, either version 3 of the License, or (at your option)
 *     any later version.
 * 
 *     Tav4SB is distributed in the hope that it will be useful, but WITHOUT ANY
 *     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *     FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
 *     more details.
 * 
 *     You should have received a copy of the GNU Affero General Public License
 *     along with Tav4SB. If not, see <http://www.gnu.org/licenses/>.
 * 
 *     Contributors:
 *         Paweł Banasik - initial implementation
 *         Michał Lula - grid implementation
 *         Mikołaj Rybiński - implementation and maintenance
 ******************************************************************************/
package pl.edu.mimuw.bioputer.tav4sb.consumer.task;

import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import org.apache.log4j.Logger;
//import pl.edu.mimuw.bioputer.tav4sb.consumer.task.TaskConsumer;
//import pl.edu.mimuw.bioputer.tav4sb.consumer.task.WorkerFactory;

/**
 *
 * @author michal
 */
public class TaskConsumerManager implements Runnable {
    private static final Logger logger = Logger.getLogger(TaskConsumerManager.class);
    private final Map<String, WorkerFactory> factories = new HashMap<String, WorkerFactory>();
    private final String brokerURL;
    private final String queueName;
    private int threadNumber = 1;

    public TaskConsumerManager(String brokerURL, String queueName) {
        this.brokerURL = brokerURL;
        this.queueName = queueName;
    }

    public void registerFactory(String s, WorkerFactory factory) {
        getFactories().put(s, factory);
    }

    public void run() {
        run(getThreadNumber());
    }

    public void run(int num) {
        List<Thread> threads = new LinkedList<Thread>();
        for (int i = 0; i < num; i++) {
            TaskConsumer consumer = new TaskConsumer(getQueueName(), getBrokerURL());
            for (Entry<String, WorkerFactory> entry : getFactories().entrySet()) {
                consumer.registerWorkerFactory(entry.getKey(), entry.getValue());
            }
            threads.add(new Thread(consumer));
        }
        for (Thread t : threads) {
            t.run();
        }
        for (Thread t : threads) {
            try {
                t.join();
            } catch (InterruptedException ex) {
                logger.error("interruption", ex);
            }
        }

    }

    /**
     * @return the factories
     */
    protected Map<String, WorkerFactory> getFactories() {
        return factories;
    }

    /**
     * @return the brokerURL
     */
    public String getBrokerURL() {
        return brokerURL;
    }

    /**
     * @return the queueName
     */
    public String getQueueName() {
        return queueName;
    }

    /**
     * @return the threadNumber
     */
    public int getThreadNumber() {
        return threadNumber;
    }

    /**
     * @param threadNumber the threadNumber to set
     */
    public void setThreadNumber(int threadNumber) {
        this.threadNumber = threadNumber;
    }

}
