/*******************************************************************************
 * Copyright (C) 2011 Mikołaj Rybiński
 * 
 *     This file is part of Tav4SB.
 * 
 *     Tav4SB is free software: you can redistribute it and/or modify it under the
 *     terms of the GNU Affero General Public License as published by the Free
 *     Software Foundation, either version 3 of the License, or (at your option)
 *     any later version.
 * 
 *     Tav4SB is distributed in the hope that it will be useful, but WITHOUT ANY
 *     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *     FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
 *     more details.
 * 
 *     You should have received a copy of the GNU Affero General Public License
 *     along with Tav4SB. If not, see <http://www.gnu.org/licenses/>.
 * 
 *     Contributors:
 *         Paweł Banasik - initial implementation
 *         Michał Lula - grid implementation
 *         Mikołaj Rybiński - implementation and maintenance
 ******************************************************************************/
package pl.edu.mimuw.bioputer.tav4sb.logic.mathematica.plot;

import com.wolfram.jlink.Expr;
import java.util.LinkedList;
import java.util.List;

import pl.edu.mimuw.bioputer.tav4sb.logic.mathematica.engine.MEngineUtils;

/**
 *
 * @author michal
 */
public abstract class AbstractPlot {
    public abstract int getDimension();

    public abstract List<PlotPoint> getPoints();

    public abstract void addPoint(PlotPoint point);

    public Expr toExpr() {
        List<Expr> list = new LinkedList<Expr>();
        for (PlotPoint point : getPoints()) {
            list.add(point.toExpr());
        }
        return MEngineUtils.list(list);
    }

    public static AbstractPlot createPlot(int dim) {
        switch (dim) {
            case Plot2D.DIMENSION:
                return new Plot2D();
            case Plot3D.DIMENSION:
                return new Plot3D();
            default:
                throw new IllegalArgumentException("unsuported dimension");
        }
    }
}
