/*******************************************************************************
 * Copyright (C) 2011 Mikołaj Rybiński
 * 
 *     This file is part of Tav4SB.
 * 
 *     Tav4SB is free software: you can redistribute it and/or modify it under the
 *     terms of the GNU Affero General Public License as published by the Free
 *     Software Foundation, either version 3 of the License, or (at your option)
 *     any later version.
 * 
 *     Tav4SB is distributed in the hope that it will be useful, but WITHOUT ANY
 *     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *     FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
 *     more details.
 * 
 *     You should have received a copy of the GNU Affero General Public License
 *     along with Tav4SB. If not, see <http://www.gnu.org/licenses/>.
 * 
 *     Contributors:
 *         Paweł Banasik - initial implementation
 *         Michał Lula - grid implementation
 *         Mikołaj Rybiński - implementation and maintenance
 ******************************************************************************/
package pl.edu.mimuw.bioputer.tav4sb.logic.mathematica.plot;

import com.wolfram.jlink.Expr;
import java.math.BigDecimal;
import java.util.LinkedList;
import java.util.List;

import pl.edu.mimuw.bioputer.tav4sb.logic.mathematica.engine.MEngineUtils;

/**
 *
 * @author michal
 */
public abstract class PlotPoint {

    public abstract int getDimension();

    public abstract List<BigDecimal> getValues();

    public Expr toExpr() {
        List<Expr> list = new LinkedList<Expr>();
        for (BigDecimal val : getValues()) {
            list.add(new Expr(val.doubleValue()));
        }
        return MEngineUtils.list(list);
    }

    public static PlotPoint getPlotPoint(List<BigDecimal> list) {
        switch (list.size()) {
            case Plot2DPoint.DIMENSION:
                return new Plot2DPoint(list.get(0), list.get(1));
            case Plot3DPoint.DIMENSION:
                return new Plot3DPoint(list.get(0),list.get(1),list.get(2));
            default:
                throw new IllegalArgumentException("unsuported dimension");
        }
    }
}
