(*******************************************************************************
*Copyright (C) 2011 Mikołaj Rybiński
*
*    This file is part of Tav4SB.
*
*    Tav4SB is free software: you can redistribute it and/or modify it under the
*    terms of the GNU Affero General Public License as published by the Free
*    Software Foundation, either version 3 of the License, or (at your option)
*    any later version.
*
*    Tav4SB is distributed in the hope that it will be useful, but WITHOUT ANY
*    WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
*    FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
*    more details.
*
*    You should have received a copy of the GNU Affero General Public License
*    along with Tav4SB. If not, see <http://www.gnu.org/licenses/>.
*
*    Contributors:
*        Paweł Banasik - initial implementation
*        Michał Lula - grid implementation
*        Mikołaj Rybiński - implementation and maintenance
*******************************************************************************)
(* ::Package:: *)

RUnifSamples[nrSamples_, nrParams_, LB_, UB_, method_] := (
    If[method=="MC",
		(* Monte Carlo - independent value for each parameter in each sample *)
        samplesMatrix = ConstantArray[0, {nrSamples, nrParams}];
        For[i = 1, i <= nrParams, i++,
            samplesMatrix[[All, i]] = RandomReal[{LB[[i]], UB[[i]]}, nrSamples]
        ]
    ,
    If[method=="LHS",
		(* Latin Hypercube Sampling *)
        P = ConstantArray[0, {nrParams, nrSamples}];
        P = Map[RandomSample[Range[nrSamples]]&, P];
        P = (P - ConstantArray[1, {nrParams, nrSamples}] 
			+ RandomReal[{0, 1}, {nrParams, nrSamples}])/nrSamples;
		(* Map value from [0..1] range to [LB..UB], for each parameter and each sample *)
        P = P * (UB - LB) + LB;
        samplesMatrix = Transpose[P]
    ,
    If[method=="MC_CARTESIAN",
		(* Cartesian product of all parameters' value sets *)
		(* Generate random value sets *)
        values = ConstantArray[0, {nrSamples, nrParams}];
        For[i = 1, i <= nrParams, i++,
            values[[All, i]] = RandomReal[{LB[[i]], UB[[i]]}, nrSamples]
        ];
		(* Compute the Cartesian product and remove duplicates *)
        t=Tuples[Table[i,{i,nrSamples}],nrParams];
        samplesMatrix = Union[Map[Table[values[[#1[[i]], i]], {i, 1, nrParams}] &, t]]
    ,
		(* Unknown method *)
        samplesMatrix = IdentityMatrix[nrParams]
    ]]];
    samplesMatrix
)

SampleParams[distribution_, scale_, method_, nr_, LB_, UB_, paramValues_, rangeMultiplier_] := (

    If[distribution=="uniform",
        samplesMatrix = RUnifSamples[nr, Length[LB], LB, UB, method];
		(* If needed, convert LINear scale to LOGarithmic *)
        If[scale=="LOG",
            samplesMatrix = Transpose[paramValues*(Power[rangeMultiplier, Transpose[samplesMatrix]])]
        ];
    ,
        samplesMatrix = IdentityMatrix[nrParams]
    ];
    samplesMatrix
)
