/*******************************************************************************
 * Copyright (C) 2011 Mikołaj Rybiński
 * 
 *     This file is part of Tav4SB.
 * 
 *     Tav4SB is free software: you can redistribute it and/or modify it under the
 *     terms of the GNU Affero General Public License as published by the Free
 *     Software Foundation, either version 3 of the License, or (at your option)
 *     any later version.
 * 
 *     Tav4SB is distributed in the hope that it will be useful, but WITHOUT ANY
 *     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *     FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
 *     more details.
 * 
 *     You should have received a copy of the GNU Affero General Public License
 *     along with Tav4SB. If not, see <http://www.gnu.org/licenses/>.
 * 
 *     Contributors:
 *         Paweł Banasik - initial implementation
 *         Michał Lula - grid implementation
 *         Mikołaj Rybiński - implementation and maintenance
 ******************************************************************************/
package pl.edu.mimuw.bioputer.tav4sb.logic.odesolver.utils;

import java.math.BigDecimal;
import pl.edu.mimuw.bioputer.tav4sb.consumer.utils.ShellWorkerProperties;

/**
 *
 * @author michal
 */
public class OdeSolverProperties extends ShellWorkerProperties {

    public static final String DEFAULT_ATOL = "ODESOLVER_DEFAULT_ATOL";
    public static final String DEFAULT_RTOL = "ODESOLVER_DEFAULT_RTOL";
    public static final String PARSER_VARLISTHEADER = "ODESOLVER_PARSER_VARLISTHEADER";
    public static final String PARSER_VARLISTSEPARATOR = "ODESOLVER_PARSER_VARLISTSEPARATOR";
    public static final String PARSER_VALLISTSEPARATOR = "ODESOLVER_PARSER_VALLISTSEPARATOR";
    public static final String PARSER_CONCENTRATIONSSEPARATOR = "ODESOLVER_PARSER_CONCENTRATIONSSEPARATOR";
    public static final String PARSER_SENSITIVITIESSEPARATOR = "ODESOLVER_PARSER_SENSITIVITIESSEPARATOR";

    @Override
    protected String getPath() {
        return "odesolver.properties";
    }

    public BigDecimal getATOL() {
        return new BigDecimal(getProperty(DEFAULT_ATOL));
    }

    public BigDecimal getRTOL() {
        return new BigDecimal(getProperty(DEFAULT_RTOL));
    }

    public String getParserConcentrationSeparator() {
        return getProperty(PARSER_CONCENTRATIONSSEPARATOR);
    }

    public String getParserSensitivitiesSeparator() {
        return getProperty(PARSER_SENSITIVITIESSEPARATOR);
    }

    public String getParserVarListHeader() {
        return getProperty(PARSER_VARLISTHEADER);
    }

    public String getParserVarListSeparator() {
        return getProperty(PARSER_VARLISTSEPARATOR);
    }

    public String getParserValListSeparator() {
        return getProperty(PARSER_VALLISTSEPARATOR);
    }
}
