/*******************************************************************************
 * Copyright (C) 2011 Mikołaj Rybiński
 * 
 *     This file is part of Tav4SB.
 * 
 *     Tav4SB is free software: you can redistribute it and/or modify it under the
 *     terms of the GNU Affero General Public License as published by the Free
 *     Software Foundation, either version 3 of the License, or (at your option)
 *     any later version.
 * 
 *     Tav4SB is distributed in the hope that it will be useful, but WITHOUT ANY
 *     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *     FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
 *     more details.
 * 
 *     You should have received a copy of the GNU Affero General Public License
 *     along with Tav4SB. If not, see <http://www.gnu.org/licenses/>.
 * 
 *     Contributors:
 *         Paweł Banasik - initial implementation
 *         Michał Lula - grid implementation
 *         Mikołaj Rybiński - implementation and maintenance
 ******************************************************************************/
package pl.edu.mimuw.bioputer.tav4sb.logic.prism;

import java.io.File;
import java.io.IOException;
import java.math.BigInteger;
import org.apache.log4j.Logger;
import pl.edu.mimuw.bioputer.tav4sb.utils.cli.JavaArgs;
import pl.edu.mimuw.bioputer.tav4sb.utils.file.RemovableFilesHolder;
import pl.edu.mimuw.bioputer.tav4sb.utils.file.SaveableString;

/**
 *
 * @author trybik
 */
public class Sbml2PrismArgs extends JavaArgs {

    private static final Logger logger = Logger.getLogger(Sbml2PrismArgs.class);
    private final RemovableFilesHolder modelHolder;
    private final String sbmlModel;
    private final BigInteger maxAmount;

    public Sbml2PrismArgs(String classpath, String sbml2prismClass, String sbmlModel, BigInteger maxAmmount) {
        super(classpath, sbml2prismClass);
        this.sbmlModel = sbmlModel;
        this.maxAmount = maxAmmount;
        this.modelHolder = createTempSbml();
    }

    public Sbml2PrismArgs(String classpath, String sbml2prismClass, String sbmlModel) {
        this(classpath, sbml2prismClass, sbmlModel, null);
    }

    public String getSbmlModel() {
        return sbmlModel;
    }

    public BigInteger getMaxAmount() {
        return maxAmount;
    }

    private RemovableFilesHolder createTempSbml() {
        try {
            File sbmlFile = File.createTempFile("tav4sb", ".xml");
            logger.debug("Created temporary model file: " + sbmlFile.getAbsolutePath());
            RemovableFilesHolder fHolder = new RemovableFilesHolder(sbmlFile);
            new SaveableString(this.sbmlModel).save(sbmlFile);
            return fHolder;
        } catch (IOException ex) {
            logger.error("Couldn't create or write to temporary SBML model file.", ex);
            throw new RuntimeException("Couldn't create or write to temporary SBML model file.", ex);
        }
    }

    private File getTempSbml() {
        return this.modelHolder.getFiles().get(0);
    }

    @Override
    public String[] getArgs() {
        String[] ret = new String[getMaxAmount() != null ? 2 : 1];
        ret[0] = getTempSbml().getAbsolutePath();
        if (getMaxAmount() != null) {
            ret[1] = maxAmount.toString();
        }
        return ret;
    }
}
