/*******************************************************************************
 * Copyright (C) 2011 Mikołaj Rybiński
 * 
 *     This file is part of Tav4SB.
 * 
 *     Tav4SB is free software: you can redistribute it and/or modify it under the
 *     terms of the GNU Affero General Public License as published by the Free
 *     Software Foundation, either version 3 of the License, or (at your option)
 *     any later version.
 * 
 *     Tav4SB is distributed in the hope that it will be useful, but WITHOUT ANY
 *     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *     FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
 *     more details.
 * 
 *     You should have received a copy of the GNU Affero General Public License
 *     along with Tav4SB. If not, see <http://www.gnu.org/licenses/>.
 * 
 *     Contributors:
 *         Paweł Banasik - initial implementation
 *         Michał Lula - grid implementation
 *         Mikołaj Rybiński - implementation and maintenance
 ******************************************************************************/
package pl.edu.mimuw.bioputer.tav4sb.logic.prism.worker;

import java.util.List;
import java.util.Scanner;
import pl.edu.mimuw.bioputer.tav4sb.consumer.task.SysCmdWorker;
import pl.edu.mimuw.bioputer.tav4sb.logic.prism.PrismModel;
import pl.edu.mimuw.bioputer.tav4sb.logic.prism.Sbml2Prism;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.prism.Sbml2PrismParams;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.prism.Sbml2PrismResult;
import pl.edu.mimuw.bioputer.tav4sb.utils.xml.XmlTranslator;
import pl.edu.mimuw.bioputer.tav4sb.utils.cli.ArgsResultsTranslator;
import pl.edu.mimuw.bioputer.tav4sb.logic.prism.Sbml2PrismArgs;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.prism.WarningsList;

/**
 *
 * @author trybik
 */
public class Sbml2PrismWorker extends SysCmdWorker<Sbml2PrismParams, Sbml2PrismArgs, PrismModel, Sbml2PrismResult> {

    private static class Sbml2PrismARTranslator
            implements ArgsResultsTranslator<Sbml2PrismParams, Sbml2PrismArgs, PrismModel, Sbml2PrismResult> {

        private final Sbml2Prism cmd;

        public Sbml2PrismARTranslator(Sbml2Prism cmd) {
            this.cmd = cmd;
        }

        private Sbml2Prism getCmd() {
            return cmd;
        }

        public Sbml2PrismArgs toInner(Sbml2PrismParams args) {
            return new Sbml2PrismArgs(getCmd().getClasspath(), getCmd().getClassname(), args.getSbmlModel(), args.getMaxAmount());
        }

        public Sbml2PrismResult toOuter(PrismModel model) {
            Sbml2PrismResult result = new Sbml2PrismResult();
            if (cmd.getOut().isEmpty() && !cmd.getErr().isEmpty()) {
                result.setError(cmd.getErr());
            } else {
                // set model element
                result.setPrismModel(model.getContent());
                // set warnings element
                // warnings list in seperate element (object) for purely
                // technical reason: this way the list is cleaner to use in
                // Taverna
                Scanner s = new Scanner(cmd.getErr());
                WarningsList warnings = new WarningsList();
                List<String> actualWarnings = warnings.getWarning();
                while (s.hasNextLine()) {
                    actualWarnings.add(s.nextLine());
                }
                result.setWarnings(warnings);
            }
            return result;
        }

    }

    public Sbml2PrismWorker(XmlTranslator<Sbml2PrismResult, Sbml2PrismParams> xmlTranslator, Sbml2Prism cmd) {
        super(xmlTranslator, cmd, new Sbml2PrismARTranslator(cmd));
    }
}
