/*******************************************************************************
 * Copyright (C) 2011 Mikołaj Rybiński
 * 
 *     This file is part of Tav4SB.
 * 
 *     Tav4SB is free software: you can redistribute it and/or modify it under the
 *     terms of the GNU Affero General Public License as published by the Free
 *     Software Foundation, either version 3 of the License, or (at your option)
 *     any later version.
 * 
 *     Tav4SB is distributed in the hope that it will be useful, but WITHOUT ANY
 *     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *     FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
 *     more details.
 * 
 *     You should have received a copy of the GNU Affero General Public License
 *     along with Tav4SB. If not, see <http://www.gnu.org/licenses/>.
 * 
 *     Contributors:
 *         Paweł Banasik - initial implementation
 *         Michał Lula - grid implementation
 *         Mikołaj Rybiński - implementation and maintenance
 ******************************************************************************/
package pl.edu.mimuw.bioputer.tav4sb.register.thread;

import javax.jms.MapMessage;
import javax.jms.Message;
import org.apache.log4j.Logger;
import pl.edu.mimuw.bioputer.tav4sb.consumer.Consumer;
import pl.edu.mimuw.bioputer.tav4sb.register.Register;

/**
 *
 * @author michal
 */
public class Recorder extends Consumer {

    public static final String TYPE = "RECORD";
    public static final String OK = "OK";
    private static final Logger logger = Logger.getLogger(Recorder.class);
    private static final String REGIST_QUANTITY = "QUANTITY";
    private static final String REGIST_EMAIL = "EMAIL";
    private static final String REGIST_TYPE = "TYPE";

    public Recorder(String queueName, String brokerURL) {
        super(brokerURL, queueName);
    }

    @Override
    public void onMessage(Message message) {
        try {
            logger.debug("(Pre) registering task");
            Register.getInstance().info();
            if (message instanceof MapMessage) {
                MapMessage mapMessage = (MapMessage) message;
                if (mapMessage.itemExists(REGIST_TYPE) & mapMessage.itemExists(REGIST_QUANTITY) &
                        mapMessage.itemExists(REGIST_EMAIL)) {
                    String type = mapMessage.getString(REGIST_TYPE);
                    String quantity = mapMessage.getString(REGIST_QUANTITY);
                    String email = mapMessage.getString(REGIST_EMAIL);
                    String id = Register.getInstance().getId();
                    Register.getInstance().register(type, id, Integer.parseInt(quantity), email);
                    reply(message, id);
                }
            }
            logger.debug("(Post) registering task");
            Register.getInstance().info();
        } catch (Exception e) {
            logger.error("exception", e);
        }
    }
}
