/*******************************************************************************
 * Copyright (C) 2011 Mikołaj Rybiński
 * 
 *     This file is part of Tav4SB.
 * 
 *     Tav4SB is free software: you can redistribute it and/or modify it under the
 *     terms of the GNU Affero General Public License as published by the Free
 *     Software Foundation, either version 3 of the License, or (at your option)
 *     any later version.
 * 
 *     Tav4SB is distributed in the hope that it will be useful, but WITHOUT ANY
 *     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *     FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
 *     more details.
 * 
 *     You should have received a copy of the GNU Affero General Public License
 *     along with Tav4SB. If not, see <http://www.gnu.org/licenses/>.
 * 
 *     Contributors:
 *         Paweł Banasik - initial implementation
 *         Michał Lula - grid implementation
 *         Mikołaj Rybiński - implementation and maintenance
 ******************************************************************************/
package pl.edu.mimuw.bioputer.tav4sb.register.utils;

import pl.edu.mimuw.bioputer.tav4sb.utils.props.QueueProperties;
import pl.edu.mimuw.bioputer.tav4sb.utils.props.PropertiesWrapper;

/**
 * Class is responsible for reading properties from configuration file.
 * File is located in resources folder. It is named register.properties.
 *
 * @author Michal Lula
 */
public class RegisterProperties extends PropertiesWrapper {

    private static final String path = "register.properties";
    private static class RegisterConsumerProperties extends QueueProperties {

        RegisterConsumerProperties(String prefix) {
            super(prefix);
        }

        @Override
        protected String getPath() {
            return path;
        }
    }
    private static final String RECORDER_PREFIX = "RECORDER";
    private static final QueueProperties recoderProps = new RegisterConsumerProperties(RECORDER_PREFIX);
    @SuppressWarnings("static-access")
    public static final String RECORDER_BROKER_URL = recoderProps.resolvePropertyName(recoderProps.BROKER_URL);
    @SuppressWarnings("static-access")
    public static final String RECORDER_QUEUE_NAME = recoderProps.resolvePropertyName(recoderProps.QUEUE_NAME);
    private static final String RECEIVER_PREFIX = "RECEIVER";
    private static final QueueProperties receiverProps = new RegisterConsumerProperties(RECEIVER_PREFIX);
    @SuppressWarnings("static-access")
    public static final String RECEIVER_BROKER_URL = receiverProps.resolvePropertyName(receiverProps.BROKER_URL);
    @SuppressWarnings("static-access")
    public static final String RECEIVER_QUEUE_NAME = receiverProps.resolvePropertyName(receiverProps.QUEUE_NAME);
    public static final String SMTP_HOST_NAME = "SMTP_HOST_NAME";
    public static final String SMTP_PORT = "SMTP_PORT";
    public static final String SMTP_LOGIN = "SMTP_LOGIN";
    public static final String SMTP_PASSWORD = "SMTP_PASSWORD";
    public static final String SMTP_STARTTLS = "SMTP_STARTTLS";
    public static final String EMAIL_FROM = "EMAIL_FROM";
    public static final String EMAIL_SIGNATURE = "EMAIL_SIGNATURE";
    public static final String EMAIL_SEND_PERIOD = "EMAIL_SEND_EVERY_MS";


    @Override
    protected String getPath() {
        return path;
    }

    /**
     * Method returns recorder broker URL.
     * @return recorder broker URL
     */
    public String getRecorderBrokerURL() {
        return recoderProps.getBrokerUrl();
    }

    /**
     * Method returns recorder queue name.
     * @return recorde queue name
     */
    public String getRecorderQueueName() {
        return recoderProps.getQueueName();
    }

    /**
     * Method returns URL to receiver queue broker.
     * @return URL to receiver queue broker
     */
    public String getReceiverBrokerURL() {
        return receiverProps.getBrokerUrl();
    }

    /**
     * Method returns receiver queue name.
     * @return name of receiver queue
     */
    public String getReceiverQueueName() {
        return receiverProps.getQueueName();
    }

    /**
     * Method returns URL to email account server.
     * @return email account server URL
     */
    public final String getSmtpHostName() {
        return getProperty(SMTP_HOST_NAME);
    }

    /**
     * Method returns smtp port to email account server.
     * @return email account port
     */
    public final String getSmtpPort() {
        return getProperty(SMTP_PORT);
    }

    /**
     * Method returns login to email account.
     * @return email account login
     */
    public final String getSmtpLogin() {
        return getProperty(SMTP_LOGIN);
    }

    public final String getSmtpStarttls() {
        return getProperty(SMTP_STARTTLS);
    }

    /**
     * Method returns password to email account.
     * @return email account password
     */
    public final String getSmtpPassword() {
        return getProperty(SMTP_PASSWORD);
    }

    public final String getEmailFrom() {
        return getProperty(EMAIL_FROM);
    }

    public final String getEmailSignature() {
        return getProperty(EMAIL_SIGNATURE);
    }

    public final String getEmailSendPeriod() {
        return getProperty(EMAIL_SEND_PERIOD);
    }
}
