/*******************************************************************************
 * Copyright (C) 2011 Mikołaj Rybiński
 * 
 *     This file is part of Tav4SB.
 * 
 *     Tav4SB is free software: you can redistribute it and/or modify it under the
 *     terms of the GNU Affero General Public License as published by the Free
 *     Software Foundation, either version 3 of the License, or (at your option)
 *     any later version.
 * 
 *     Tav4SB is distributed in the hope that it will be useful, but WITHOUT ANY
 *     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *     FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
 *     more details.
 * 
 *     You should have received a copy of the GNU Affero General Public License
 *     along with Tav4SB. If not, see <http://www.gnu.org/licenses/>.
 * 
 *     Contributors:
 *         Paweł Banasik - initial implementation
 *         Michał Lula - grid implementation
 *         Mikołaj Rybiński - implementation and maintenance
 ******************************************************************************/
package pl.edu.mimuw.bioputer.tav4sb.utils.props;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;
import org.apache.log4j.Logger;

/**
 *
 * @author michal
 */
public class PropertiesManager {

    private static final Logger logger = Logger.getLogger(PropertiesManager.class);
    private final Properties properties = new Properties();

    public PropertiesManager(InputStream stream) throws IOException {
        properties.load(stream);
    }

    public PropertiesManager(String path, ClassLoader loader) throws IOException {
        this(loader.getResourceAsStream(path));
    }

    public Properties getProperties() {
        return properties;
    }

    public String getProperty(String key) throws PropertyNotFoundException {
        logger.debug("key = " + key);
        String prop = getProperties().getProperty(key);
        if (prop == null) {
            logger.error("Property named \""+key+"\" has not been found.");
            throw new PropertyNotFoundException("Property named \""+key+"\" has not been found.");
        }
        return prop;
    }
}
