/*******************************************************************************
 * Copyright (C) 2011 Mikołaj Rybiński
 * 
 *     This file is part of Tav4SB.
 * 
 *     Tav4SB is free software: you can redistribute it and/or modify it under the
 *     terms of the GNU Affero General Public License as published by the Free
 *     Software Foundation, either version 3 of the License, or (at your option)
 *     any later version.
 * 
 *     Tav4SB is distributed in the hope that it will be useful, but WITHOUT ANY
 *     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *     FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
 *     more details.
 * 
 *     You should have received a copy of the GNU Affero General Public License
 *     along with Tav4SB. If not, see <http://www.gnu.org/licenses/>.
 * 
 *     Contributors:
 *         Paweł Banasik - initial implementation
 *         Michał Lula - grid implementation
 *         Mikołaj Rybiński - implementation and maintenance
 ******************************************************************************/
package pl.edu.mimuw.bioputer.tav4sb.service.messages;

import java.math.BigDecimal;
import java.util.LinkedList;
import java.util.List;
import pl.edu.mimuw.bioputer.tav4sb.service.utils.WSProperties;
import pl.edu.mimuw.bioputer.tav4sb.services.wsdl.PrismParamsCompact;
import pl.edu.mimuw.bioputer.tav4sb.services.wsdl.FiniteValues;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.prism.PrismParams;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.prism.PrismResult;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.prism.FiniteValue;

/**
 *
 * @author michal
 */
public class PrismMessage extends WsMessage<PrismParamsCompact, PrismParams, PrismResult, PrismResult> {

    private final List<PrismParams> objectList = new LinkedList<PrismParams>();
    public static final String context = "pl.edu.mimuw.bioputer.tav4sb.services.xsd.prism";
    public static final String NAME = "prism";
    private static final WSProperties props = new WSProperties(NAME);

    public PrismMessage(PrismParamsCompact param) {
        super(param, props);
        addObjects(toValueListList(param.getConstantCompact()));
    }

    @Override
    protected String getContext() {
        return context;
    }

    private List<List<FiniteValue>> toValueListList(List<FiniteValues> constVal) {
        List<List<FiniteValue>> result = new LinkedList<List<FiniteValue>>();
        for (FiniteValues cv : constVal) {
            List<FiniteValue> list = new LinkedList<FiniteValue>();
            for (BigDecimal bd : cv.getValue()) {
                FiniteValue val = new FiniteValue();
                val.setName(cv.getName());
                val.setValue(bd);
                list.add(val);
            }
            result.add(list);
        }
        return result;
    }

    private void addObjects(List<List<FiniteValue>> list) {
        doAddObjects(list, new LinkedList<FiniteValue>());
    }

    private void doAddObjects(List<List<FiniteValue>> constValList, List<FiniteValue> valList) {
        if (constValList.isEmpty()) {
            PrismParams p = new PrismParams();
            p.setProperties(getParam().getProperties());
            p.setModel(getParam().getModel());
            p.getConstant().addAll(valList);
            getObjectList().add(p);
            return;
        }
        List<FiniteValue> cv = constValList.remove(0);
        for (FiniteValue val : cv) {
            valList.add(val);
            doAddObjects(constValList, valList);
            valList.remove(val);
        }
        constValList.add(cv);
    }

    @Override
    protected List<PrismParams> getObjectList() {
        return this.objectList;
    }

    @Override
    public PrismResult getResult() {
        PrismResult result = new PrismResult();
        for (PrismResult res : getResultList()) {
            result.getResult().addAll(res.getResult());
        }
        return result;
    }
}
