/*******************************************************************************
 * Copyright (C) 2011 Mikołaj Rybiński
 * 
 *     This file is part of Tav4SB.
 * 
 *     Tav4SB is free software: you can redistribute it and/or modify it under the
 *     terms of the GNU Affero General Public License as published by the Free
 *     Software Foundation, either version 3 of the License, or (at your option)
 *     any later version.
 * 
 *     Tav4SB is distributed in the hope that it will be useful, but WITHOUT ANY
 *     WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *     FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
 *     more details.
 * 
 *     You should have received a copy of the GNU Affero General Public License
 *     along with Tav4SB. If not, see <http://www.gnu.org/licenses/>.
 * 
 *     Contributors:
 *         Paweł Banasik - initial implementation
 *         Michał Lula - grid implementation
 *         Mikołaj Rybiński - implementation and maintenance
 ******************************************************************************/
package pl.edu.mimuw.bioputer.tav4sb.service;

import org.junit.Ignore;
import org.junit.Test;

import pl.edu.mimuw.bioputer.tav4sb.services.xsd.mathematica.CalcSensitivityParams;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.mathematica.CalcSensitivityResult;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.mathematica.ClassifySamplesParams;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.mathematica.ClassifySamplesResult;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.mathematica.MathPlotParams;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.mathematica.MathPlotResult;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.mathematica.PlotTrajectories3DParams;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.mathematica.PlotTrajectories3DResult;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.mathematica.PlotTrajectoriesParams;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.mathematica.PlotTrajectoriesResult;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.mathematica.SampleParamsParams;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.mathematica.SampleParamsResult;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.mathematica.SelectObservablesParams;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.mathematica.SelectObservablesResult;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.mathematica.SelectThresholdParams;
import pl.edu.mimuw.bioputer.tav4sb.services.xsd.mathematica.SelectThresholdResult;

public class MathematicaTest extends Tav4SBPortTypeImplAbstractTest {
    private static final String testSelectThreshold = "testSelectThreshold";
    private static final String testSelectObservables = "testSelectObservables";
    private static final String testPlotTrajectories = "testPlotTrajectories";
    private static final String testPlotTrajectories3D = "testPlotTrajectories3D";
    private static final String testCalcSensitivity = "testCalcSensitivity";
    private static final String testSampleParams = "testSampleParams";
    private static final String testClassifySamples = "testClassifySamples";
    private static final String testMathPlot = "testMathPlot";

    @Ignore
    @Test
    public void testSelectThreshold() {
        Executor<SelectThresholdParams, SelectThresholdResult> exec = new Executor<SelectThresholdParams, SelectThresholdResult>(testSelectThreshold) {

            @Override
            protected SelectThresholdResult doTest(SelectThresholdParams param, Tav4SBPortTypeImpl instance) throws Exception {
                return instance.selectThreshold(param);
            }
        };
        exec.test(SelectThresholdParams.class, SelectThresholdResult.class);
    }

    @Ignore
    @Test
    public void testSelectObservables() {
        Executor<SelectObservablesParams, SelectObservablesResult> exec = new Executor<SelectObservablesParams, SelectObservablesResult>(testSelectObservables) {

            @Override
            protected SelectObservablesResult doTest(SelectObservablesParams param, Tav4SBPortTypeImpl instance) throws Exception {
                return instance.selectObservables(param);
            }
        };
        exec.test(SelectObservablesParams.class, SelectObservablesResult.class);
    }

    @Ignore
    @Test
    public void testPlotTrajectories() {
        Executor<PlotTrajectoriesParams, PlotTrajectoriesResult> exec = new Executor<PlotTrajectoriesParams, PlotTrajectoriesResult>(testPlotTrajectories) {

            @Override
            protected PlotTrajectoriesResult doTest(PlotTrajectoriesParams param, Tav4SBPortTypeImpl instance) throws Exception {
                return instance.plotTrajectories(param);
            }
        };
        exec.test(PlotTrajectoriesParams.class, PlotTrajectoriesResult.class);
    }

    @Ignore
    @Test
    public void testPlotTrajectories3D() {
        Executor<PlotTrajectories3DParams, PlotTrajectories3DResult> exec = new Executor<PlotTrajectories3DParams, PlotTrajectories3DResult>(testPlotTrajectories3D) {

            @Override
            protected PlotTrajectories3DResult doTest(PlotTrajectories3DParams param, Tav4SBPortTypeImpl instance) throws Exception {
                return instance.plotTrajectories3D(param);
            }
        };
        exec.test(PlotTrajectories3DParams.class, PlotTrajectories3DResult.class);
    }

    @Ignore
    @Test
    public void testCalcSensitivity() {
        Executor<CalcSensitivityParams, CalcSensitivityResult> exec = new Executor<CalcSensitivityParams, CalcSensitivityResult>(testCalcSensitivity) {

            @Override
            protected CalcSensitivityResult doTest(CalcSensitivityParams param, Tav4SBPortTypeImpl instance) throws Exception {
                return instance.calcSensitivity(param);
            }
        };
        exec.test(CalcSensitivityParams.class, CalcSensitivityResult.class);
    }

    @Test
    public void testSampleParams() {
        Executor<SampleParamsParams, SampleParamsResult> exec = new Executor<SampleParamsParams, SampleParamsResult>(testSampleParams) {

            @Override
            protected SampleParamsResult doTest(SampleParamsParams param, Tav4SBPortTypeImpl instance) throws Exception {
                return instance.sampleParams(param);
            }
        };
        exec.test(SampleParamsParams.class, SampleParamsResult.class);
    }

    @Test
    public void testClassifySamples() {
        Executor<ClassifySamplesParams, ClassifySamplesResult> exec = new Executor<ClassifySamplesParams, ClassifySamplesResult>(testClassifySamples) {

            @Override
            protected ClassifySamplesResult doTest(ClassifySamplesParams param, Tav4SBPortTypeImpl instance) throws Exception {
                return instance.classifySamples(param);
            }
        };
        exec.test(ClassifySamplesParams.class, ClassifySamplesResult.class);
    }

    @Test
    public void testMathPlot() {
        Executor<MathPlotParams, MathPlotResult> exec = new Executor<MathPlotParams, MathPlotResult>(testMathPlot) {

            @Override
            protected MathPlotResult doTest(MathPlotParams param, Tav4SBPortTypeImpl instance) throws Exception {
                return instance.mathPlot(param);
            }
        };
        exec.test(MathPlotParams.class, MathPlotResult.class);
    }

}
